<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>Películas Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Cinema Deepin es un reproductor de vídeo de altas prestaciones, posee un diseño elegante sin bordes. Es compatible con la reproducción de medios locales y streaming soportando múltiples formatos de vídeo.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Carpeta no válida</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open folder</source>
        <translation>Abrir Carpeta</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>No tiene permiso para operar esta carpeta</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Agregar automáticamente archivos similares para reproducir</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Borrar lista de reproducción al salir</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Mostrar vista previa del vídeo con el puntero</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Abrir un nuevo reproductor para cada archivo reproducido</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Pausar al minimizar</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Recordar la posición de reproducción</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Ruta de acceso</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Cuadro/Sonido</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Reproducción</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Subtítulos</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Estilo de fuente</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Restaurar los valores predeterminados</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Abrir siguiente</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Abrir anterior</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Modo miniatura</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation>Siguiente fotograma</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation>Anterior fotograma</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Volume down</source>
        <translation>Bajar volumen</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>Subir volumen</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>Acelerar</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>Ralentizar</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>Pausar/Reproducir</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>Normalizar velocidad</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>Retroceder</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>Adelantar</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>Captura de pantalla de ráfaga</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>Captura de pantalla de vídeo</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>Avanzar 0.5s</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>Retroceder 0.5s</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>Tamaño de la fuente</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Por favor, ingrese la URL:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Siempre al frente</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>Detalle del vídeo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open folder</source>
        <translation>Abrir Carpeta</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light theme</source>
        <translation>Tema Claro</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Abrir URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Abrir CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Modo Miniatura</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Modo reproducción</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Reproducir en orden</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Reproducir al azar</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Reproducir una vez</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Repetición simple</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Repetición en lista</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Cuadro</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>Giro horario</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Giro antihorario</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation>Siguiente fotograma</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation>Anterior fotograma</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>Estéreo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>Canal izquierdo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>Canal derecho</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>Pista</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>Subtítulo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>Búsqueda en línea</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>Esconder</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>Codificación de datos</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>Captura de vídeo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>Captura de movimiento</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>Detalle del vídeo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>Borrar lista de reproducción</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>Mostrar en administrador de archivos</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>Duration: %1</source>
        <translation>Duración %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>Resolution: %1</source>
        <translation>Resolución %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>Size: %1</source>
        <translation>Tamaño %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load successfully</source>
        <translation>Carga exitosa</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load failed</source>
        <translation>Carga fallida</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1424"/>
        <source>No device found</source>
        <translation>Dispositivo no encontrado</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <source>Parse Failed</source>
        <translation>Pase fallido</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <source>Open folder</source>
        <translation>Abrir Carpeta</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1464"/>
        <location filename="../common/mainwindow.cpp" line="1481"/>
        <location filename="../common/mainwindow.cpp" line="1816"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1466"/>
        <location filename="../common/mainwindow.cpp" line="1483"/>
        <source>All videos (%1)</source>
        <translation>Todos los videos (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Muted</source>
        <translation>Silenciado</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1687"/>
        <location filename="../common/mainwindow.cpp" line="1699"/>
        <location filename="../common/mainwindow.cpp" line="1709"/>
        <location filename="../common/mainwindow.cpp" line="1716"/>
        <source>Volume: %1%</source>
        <translation>Volumen: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1781"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Subtitle %1: %2s</source>
        <translation>Subtítulo %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>delayed</source>
        <translation>retrasado</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>advanced</source>
        <translation>avanzado</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1797"/>
        <location filename="../common/mainwindow.cpp" line="1804"/>
        <location filename="../common/mainwindow.cpp" line="1811"/>
        <source>Speed: %1x</source>
        <translation>Velocidad: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1818"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <translation>Subtitulos (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1880"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1891"/>
        <source>Movie Screenshot</source>
        <translation>Captura de pantalla de vídeo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1892"/>
        <source>Saved to</source>
        <translation>Guardado a</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <location filename="../common/mainwindow.cpp" line="1989"/>
        <source>The screenshot is saved</source>
        <translation>La captura de pantalla fue guardada</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <source>Failed to save the screenshot</source>
        <translation>Error al guardar la captura de pantalla</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2076"/>
        <location filename="../common/mainwindow.cpp" line="2782"/>
        <source>Invalid file: %1</source>
        <translation>Archivo inválido: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <location filename="../libdmr/playlist_model.h" line="67"/>
        <source>%1G</source>
        <translation>%1G</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="69"/>
        <source>%1M</source>
        <translation>%1M</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="71"/>
        <source>%1K</source>
        <translation>%1K</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="73"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Tipo de archivo:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Resolución:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Tamaño archivo:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Ruta del archivo:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
        <source>[internal]</source>
        <translation>[interno]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>El archivo no existe</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Subtitulos</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar </translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Salir de pantalla completa</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
</context>
</TS>